@@ -1,3 +1,7 @@
+"""Collection of 1D Elements
+"""
+
+
 from .Element1D import *
 from .LinealElement import *
 from .QuadraticElement import *
